---
title: Block Zeichnungstypen
layout: default
root: ../..
idx: 2.3
description: Ratgeber für alle Zeichnungstypen, einschließlich node boxen/Nodeboxen und mesh nodes.
redirect_from: /de/chapters/node_drawtypes.html
---

## Einleitung <!-- omit in toc -->

Die Methode, mit der ein Block gezeichnet wird, wird als *Zeichnungstyp* bezeichnet. Es gibt viele
verfügbare Zeichnungstypen. Das Verhalten eines Zeichnungstyp kann gesteuert werden
durch Angabe von Eigenschaften in der Blocktypdefinition gesteuert werden. Diese Eigenschaften
sind für alle Instanzen dieses Knotens festgelegt. Es ist möglich, einige Eigenschaften
pro Knoten zu steuern, indem man etwas namens `param2` verwendet.

Im vorigen Kapitel wurde das Konzept der Blöcke und Items eingeführt, aber eine
vollständige Definition eines Blockes wurde nicht gegeben. Die Minetest-Welt ist ein 3D-Gitter aus
Positionen. Jede Position wird als Block bezeichnet und besteht aus dem Blocktyp
(Name) und zwei Parametern (param1 und param2). Die Funktion
`minetest.register_node` (übersetzt `minetest.registriere_Block`)ist ein wenig irreführend, da sie nicht wirklich
einen Knoten registriert - sie registriert einen neuen *Typ* von Block.

Die Blockparameter werden verwendet, um zu steuern, wie ein Block individuell gerendert wird.
`param1` wird verwendet, um die Beleuchtung eines Blockes zu speichern, und die Bedeutung von
`param2` hängt von der Eigenschaft `paramtype2` der Blocktypdefinition ab.

- [Würfelförmiger Block: Normale und allfaces](#würfelförmiger-block-normale-und-allfaces)
- [Glasartige Blöcke](#glasartige-blöcke)
	- [Glasartig gerahmt](#glasartig-gerahmt)
- [Airlike Nodes](#airlike-nodes)
- [Lighting and Sunlight Propagation](#lighting-and-sunlight-propagation)
- [Flüssige Blöcke](#flüssige-blöcke)
- [Nodeboxen](#nodeboxen)
	- [Wandgehaltene Nodeboxen](#wandgehaltene-nodeboxen)
- [Mesh Nodes](#mesh-nodes)
- [Signlike Nodes](#signlike-nodes)
- [Plantlike Nodes](#plantlike-nodes)
- [Firelike Nodes](#firelike-nodes)
- [Mehr Zeichnungstypen](#mehr-zeichnungstypen)


## Würfelförmiger Block: Normale und allfaces

<figure class="right_image">
    <img src="{{ page.root }}//static/drawtype_normal.png" alt="Normaler Zeichnungstyp">
    <figcaption>
        Normaler Zeichnungstyp
    </figcaption>
</figure>

Der Zeichnungstyp normal wird normalerweise zum Rendern eines Würfelförmigen Blockes verwendet.
Wenn die Seite eines normalen Blockes an einer festen Seite anliegt, wird diese Seite nicht gerendert,
was zu einem großen Leistungsgewinn führt.

Im Gegensatz dazu wird der Zeichnungstyp allfaces immer noch die Innenseite darstellen, wenn er auf einen
soliden Block ist. Dies ist gut für Blöcke mit teilweise transparenten Seiten, wie z.B. den
Blatt-Block. Sie können den allfaces_optional drawtype verwenden, um den Benutzern die Möglichkeit zu geben, die
langsamere Zeichnen auszuschalten, in diesem Fall verhält er sich wie ein normaler Block.

```lua
minetest.register_node("meinemod:diamant", {
    description = "Alien Diamant",
    tiles = {"meinemod_diamant.png"},
    groups = {cracky = 3},
})

minetest.register_node("default:leaves", {
    description = "Blätter",
    drawtype = "allfaces_optional",
    tiles = {"default_leaves.png"}
})
```

Hinweis: Der normale Zeichentyp ist der Standard-Zeichentyp, Sie müssen ihn also nicht explizit
angeben.


## Glasartige Blöcke

Der Unterschied zwischen glasartigen(glasslike) und normalen Blöcken besteht darin, dass die Platzierung eines glasartigen Blockes
neben einem normalen Block platziert wird, nicht dazu führt, dass die Seite des normalen Blockes ausgeblendet wird.
Dies ist nützlich, weil glasartige Block dazu neigen, transparent zu sein, und daher die Verwendung eines normalen
Drawtype dazu führen würde, dass man durch die Welt hindurchsehen kann.

<figure>
    <img src="{{ page.root }}//static/drawtype_glasslike_edges.png" alt="Glasartige Ränder">
    <figcaption>
        Glasartige Ränder
    </figcaption>
</figure>

```lua
minetest.register_node("default:obsidian_glass", {
    description = "Obsidian Glas",
    drawtype = "glasslike",
    tiles = {"default_obsidian_glass.png"},
    paramtype = "light",
    is_ground_content = false,
    sunlight_propagates = true,
    sounds = default.node_sound_glass_defaults(),
    groups = {cracky=3,oddly_breakable_by_hand=3},
})
```

### Glasartig gerahmt

Dies führt dazu, dass die Kante des Blockes mit einem 3D-Effekt um das ganze Ding herumgeht und nicht
als um einzelne Block, wie im Folgenden dargestellt:

<figure>
    <img src="{{ page.root }}//static/drawtype_glasslike_framed.png" alt="Glasartig gerahmt Ränder">
    <figcaption>
        Glasartig gerahmt Ränder
    </figcaption>
</figure>

Sie können den Zeichnungstyp `glasslike_framed_optional` verwenden, um dem Benutzer die Möglichkeit zu geben, *opt-in*
in das gerahmte Erscheinungsbild.

```lua
minetest.register_node("default:glass", {
    description = "Glas",
    drawtype = "glasslike_framed",
    tiles = {"default_glass.png", "default_glass_detail.png"},
    inventory_image = minetest.inventorycube("default_glass.png"),
    paramtype = "light",
    sunlight_propagates = true, -- Sonnenlicht kann durch den Block scheinen
    groups = {cracky = 3, oddly_breakable_by_hand = 3},
    sounds = default.node_sound_glass_defaults()
})
```


## Luftartige Blöcke

Diese Blöcke werden nicht gerendert und haben daher keine Texturen.

```lua
minetest.register_node("meineluft:luft", {
    description = "MeineLuft (Du hacker du!)",
    drawtype = "airlike",
    paramtype = "light",
    sunlight_propagates = true,

    walkable     = false, -- Würde den Spieler mit dem Luftblock kollidieren lassen
    pointable    = false, -- Sie können den Block nicht auswählen
    diggable     = false, -- Sie können den Block nicht abbauen
    buildable_to = true,  -- Blöcke können diesen Block ersetzen
                          -- (Sie können einen Block platzieren und den Luftblock 
                          -- entfernen die früher einmal da waren)

    air_equivalent = true,
    drop = "",
    groups = {not_in_creative_inventory=1}
})
```


## Beleuchtung und Sonnenlichtausbreitung

Die Beleuchtung eines Blockes wird in param1 gespeichert. Um herauszufinden, wie man die
Seite eines Blockes zu schattieren hat, wird der Lichtwert des benachbarten Blockes verwendet.
Aus diesem Grund haben solide Blöcke keine Lichtwerte, da sie das Licht blockieren.

Standardmäßig lässt ein Blocktyp nicht zu, dass Licht in Blockinstanzen gespeichert wird.
Es ist normalerweise wünschenswert, dass einige Blöcke wie Glas und Luft in der Lage sind
Licht durchzulassen. Zu diesem Zweck müssen zwei Eigenschaften definiert werden:

```lua
paramtype = "light",
sunlight_propagates = true,
```

Die erste Zeile bedeutet, dass param1 in der Tat den Lichtwert speichert.
Die zweite Zeile bedeutet, dass das Sonnenlicht diesen Knoten durchlaufen sollte, ohne an Wert zu verlieren.

## Flüssige Blöcke

<figure class="right_image">
    <img src="{{ page.root }}//static/drawtype_liquid.png" alt="Flüssigkeiten Zeichnungstyp">
    <figcaption>
        Flüssigkeiten Zeichnungstyp
    </figcaption>
</figure>

Jede Art von Flüssigkeit erfordert zwei Blockdefinitionen - eine für die Flüssigkeitsquelle und
eine weitere für die fließende Flüssigkeit.

```lua
-- Einige Eigenschaften wurden entfernt, da sie nicht mehr
-- den Anwendungsbereich dieses Kapitels entsprechen.
minetest.register_node("default:water_source", {
    drawtype = "liquid",
    paramtype = "light",

    inventory_image = minetest.inventorycube("default_water.png"),
    -- ^ dies ist erforderlich, damit das Inventarbild nicht auch animiert wird

    tiles = {
        {
            name = "default_water_source_animated.png",
            animation = {
                type     = "vertical_frames",
                aspect_w = 16,
                aspect_h = 16,
                length   = 2.0
            }
        }
    },

    special_tiles = {
        -- Wasserquellenmaterial neuen Typs (größtenteils unbenutzt)
        {
            name      = "default_water_source_animated.png",
            animation = {type = "vertical_frames", aspect_w = 16,
                aspect_h = 16, length = 2.0},
            backface_culling = false,
        }
    },

    --
    -- Behavior
    --
    walkable     = false, -- Der Spieler fällt durch
    pointable    = false, -- Der Spieler kann es nicht auswählen
    diggable     = false, -- Der Spieler kann es nicht abbauen
    buildable_to = true,  -- Blöcke können diesen Block ersetzen

    alpha = 160,

    --
    -- Flüssigkeits Eigenschaften
    --
    drowning = 1,
    liquidtype = "source",

    liquid_alternative_flowing = "default:water_flowing",
    -- ^ wenn die Flüssigkeit fließt

    liquid_alternative_source = "default:water_source",
    -- ^ wenn die Flüssigkeit eine Quelle ist

    liquid_viscosity = WATER_VISC,
    -- ^ wie schnell

    liquid_range = 8,
    -- ^ wie weit

    post_effect_color = {a=64, r=100, g=100, b=200},
    -- ^ Farbe des Bildschirms, wenn der Spieler untergetaucht ist
})
```

Fließende Blöcke haben eine ähnliche Definition, allerdings mit einem anderen Namen und einer anderen Animation.
Siehe `default:water_flowing` in der Standard-Mod in `minetest_game` für ein vollständiges Beispiel.

## Nodeboxen

<figure class="right_image">
    <img src="{{ page.root }}//static/drawtype_nodebox.gif" alt="Nodebox Zeichnungstyp">
    <figcaption>
        Nodebox Zeichnungstyp
    </figcaption>
</figure>

Mit Nodeboxen können Sie einen Block erstellen, der nicht würfelförmig ist, sondern
aus beliebig vielen Quadern besteht.

```lua
minetest.register_node("stairs:stair_stone", {
    drawtype = "nodebox",
    paramtype = "light",
    node_box = {
        type = "fixed",
        fixed = {
            {-0.5, -0.5, -0.5, 0.5, 0, 0.5},
            {-0.5, 0, 0, 0.5, 0.5, 0.5},
        },
    }
})
```

Der wichtigste Teil ist die Nodebox-Tabelle:

```lua
{-0.5, -0.5, -0.5,       0.5,    0,  0.5},
{-0.5,    0,    0,       0.5,  0.5,  0.5}
```

Jede Zeile ist ein Quader, der zu einem einzigen Blockpunkt verbunden ist.
Die ersten drei Zahlen sind die Koordinaten (von -0,5 bis einschließlich 0,5) der
der unteren, vorderen, linken Ecke, die letzten drei Zahlen sind die gegenüberliegende Ecke.
Sie haben die Form X, Y, Z, wobei Y für oben steht.

Du kannst den [NodeBoxEditor](https://forum.minetest.net/viewtopic.php?f=14&t=2840) benutzen um
Erstellen Sie Nodeboxen durch Ziehen der Kanten, das ist anschaulicher als die Arbeit von Hand.


### Wandgehaltene Nodeboxen

Manchmal möchte man verschiedene Nodeboxen für die Platzierung auf dem Boden, an der Wand oder an der Decke wie bei Fackeln.

```lua
minetest.register_node("default:sign_wall", {
    drawtype = "nodebox",
    node_box = {
        type = "wallmounted",

        -- Ceiling
        wall_top    = {
            {-0.4375, 0.4375, -0.3125, 0.4375, 0.5, 0.3125}
        },

        -- Floor
        wall_bottom = {
            {-0.4375, -0.5, -0.3125, 0.4375, -0.4375, 0.3125}
        },

        -- Wall
        wall_side   = {
            {-0.5, -0.3125, -0.4375, -0.4375, 0.3125, 0.4375}
        }
    },
})
```

## Mesh Nodes

Nodeboxen sind zwar im Allgemeinen einfacher zu erstellen, doch sind sie insofern eingeschränkt, als
sie nur aus Quadern bestehen können. Nodeboxen sind außerdem nicht optimiert;
Innenflächen werden auch dann noch gerendert, wenn sie vollständig ausgeblendet sind.

Eine Fläche ist eine ebene Oberfläche in einem Mesh(Netz). Eine innere Fläche entsteht, wenn sich die Flächen von zwei
verschiedenen Nodeboxen überlappen, wodurch Teile des Nodebox-Modells
unsichtbar sind, aber dennoch gerendert werden.

So können Sie ein mesh node registrieren:

```lua
minetest.register_node("mymod:meshy", {
    drawtype = "mesh",

    -- Enthält die Textur für jedes "material"
    tiles = {
        "mymod_meshy.png"
    },

    -- Verzeichnis zum Mesh
    mesh = "mymod_meshy.b3d",
})
```

Vergewissern Sie sich, dass das Mesh in einem `models`-Verzeichnis verfügbar ist.
Meistens sollte sich das Mesh im eigenen Mod-Ordner befinden, aber es ist auch in Ordnung, wenn
ein Mesh zu verwenden, das von einem anderen Mod bereitgestellt wird, von dem du abhängig bist. Zum Beispiel kann ein Mod, der
weitere Möbeltypen hinzufügt, das Modell einer grundlegenden
Möbel-Mod sein.


## Signlike Nodes

Signlike nodes  sind flache Knoten, die an den Seiten anderer Knoten angebracht werden können.
Trotz des Namens dieses Zeichentyps verwenden Schilder in der Regel nicht signlike,
sondern verwenden stattdessen den Zeichnungstyp `Nodebox`, um einen 3D-Effekt zu erzielen. Der Zeichentyp `signlike`
wird jedoch häufig von Leitern verwendet.

```lua
minetest.register_node("default:ladder_wood", {
    drawtype = "signlike",

    tiles = {"default_ladder_wood.png"},

    -- Erforderlich: Speichern der Drehung in param2
    paramtype2 = "wallmounted",

    selection_box = {
        type = "wallmounted",
    },
})
```


## Plantlike Nodes

<figure class="right_image">
    <img src="{{ page.root }}//static/drawtype_plantlike.png" alt="Plantlike Zeichnungstyp">
    <figcaption>
        Plantlike Zeichnungstyp
    </figcaption>
</figure>

Plantlike Nodes ziehen ihre Kacheln in einem X-ähnlichen Muster.

```lua
minetest.register_node("default:papyrus", {
    drawtype = "plantlike",

    -- Nur eine Textur in Verwendung
    tiles = {"default_papyrus.png"},

    selection_box = {
        type = "fixed",
        fixed = {-6 / 16, -0.5, -6 / 16, 6 / 16, 0.5, 6 / 16},
    },
})
```

## Firelike Nodes

Firelike ist ähnlich zu plantlike, mit der Ausnahme, dass es so konzipiert ist für 
Wände und Decken.

<figure>
    <img src="{{ page.root }}//static/drawtype_firelike.png" alt="Firelike nodes">
    <figcaption>
        Firelike nodes
    </figcaption>
</figure>

```lua
minetest.register_node("meinemod:klinger", {
    drawtype = "firelike",

    -- Nur eine Textur in Verwendung
    tiles = { "mymod:klinger" },
})
```

## Mehr Zeichnungstypen

Dies ist keine vollständige Liste, es gibt noch weitere Arten:

* Fencelike
* Plantlike rooted - für Unterwasser-Pflanzen
* Raillike - für Schienen
* Torchlike - für 2D Wand/Boden/Decken-Blöcke.
  Die Fackeln in Minetest Game verwenden zwei verschiedene Block-Definitionen von
  mesh nodes (default:torch und default:torch_wall).

Und lese immer [Lua API dokumentation](https://minetest.gitlab.io/minetest/nodes/#node-drawtypes)
für eine komplette Liste.
